# Table of Contents

- [Table of Contents](#table-of-contents)
- [About](#about)
  - [Operating System Support](#operating-system-support)
  - [Python Version Support](#python-version-support)

# About

`ni.datamonikers.v1.client` is a Python package that provides a gRPC client for the
NI Data Moniker Service, version 1. The corresponding service is defined in the
[ni.datamonikers.v1 package](https://github.com/ni/ni-apis/tree/main/ni/datamonikers/v1).

NI created and supports this package.

## Operating System Support

`ni.datamonikers.v1.client` supports Windows operating systems.

## Python Version Support

`ni.datamonikers.v1.client` supports CPython 3.9+.

## Installation

You can directly install the `ni.datamonikers.v1.client` package using `pip` or by listing it as a
dependency in your project's `pyproject.toml` file.